"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CompassFavoriteQueryStorage = exports.CompassRecentQueryStorage = exports.CompassQueryStorage = void 0;
const bson_1 = require("bson");
const compass_user_data_1 = require("@mongodb-js/compass-user-data");
const query_storage_schema_1 = require("./query-storage-schema");
class CompassQueryStorage {
    constructor(schemaValidator, folder, options) {
        this.folder = folder;
        this.options = options;
        // TODO: logic for whether we're in compass web or compass desktop
        this.userData = new compass_user_data_1.FileUserData(schemaValidator, {
            subdir: folder,
            basePath: options.basepath,
            serialize: (content) => bson_1.EJSON.stringify(content, undefined, 2),
            deserialize: (content) => bson_1.EJSON.parse(content),
        });
    }
    async loadAll(namespace) {
        try {
            const { data } = await this.userData.readAll();
            const sortedData = data
                .sort((a, b) => {
                return b._lastExecuted.getTime() - a._lastExecuted.getTime();
            })
                .filter((x) => !namespace || x._ns === namespace);
            return sortedData;
        }
        catch {
            return [];
        }
    }
    async write(id, content) {
        return await this.userData.write(id, content);
    }
    async delete(id) {
        return await this.userData.delete(id);
    }
    async updateAttributes(id, data) {
        return await this.userData.updateAttributes(id, data);
    }
}
exports.CompassQueryStorage = CompassQueryStorage;
class CompassRecentQueryStorage extends CompassQueryStorage {
    constructor(options = {}) {
        super(query_storage_schema_1.RecentQuerySchema, 'RecentQueries', options);
        this.maxAllowedQueries = 30;
    }
    async saveQuery(data) {
        const recentQueries = await this.loadAll();
        if (recentQueries.length >= this.maxAllowedQueries) {
            const lastRecent = recentQueries[recentQueries.length - 1];
            await this.delete(lastRecent._id);
        }
        const _id = new bson_1.UUID().toString();
        // this creates a recent query that we will write to system/db
        const recentQuery = {
            ...data,
            _id,
            _lastExecuted: new Date(),
        };
        await this.userData.write(_id, recentQuery);
    }
}
exports.CompassRecentQueryStorage = CompassRecentQueryStorage;
class CompassFavoriteQueryStorage extends CompassQueryStorage {
    constructor(options = {}) {
        super(query_storage_schema_1.FavoriteQuerySchema, 'FavoriteQueries', options);
    }
    async saveQuery(data) {
        const _id = new bson_1.UUID().toString();
        // this creates a favorite query that we will write to system/db
        const favoriteQuery = {
            ...data,
            _id,
            _lastExecuted: new Date(),
            _dateSaved: new Date(),
        };
        await this.userData.write(_id, favoriteQuery);
    }
}
exports.CompassFavoriteQueryStorage = CompassFavoriteQueryStorage;
//# sourceMappingURL=compass-query-storage.js.map